@@ -17,13 +17,24 @@ class GeneralTaskModule(LightningModule):
     def forward(self, *batch_data):                         # 前向计算
         return self.model(*batch_data)
 
+    def on_train_start(self):
+        self.metrics ={
+            'train': [m.to(self.device) for m in self.metrics['train'] if isinstance(m, Metric)],
+            'val': [m.to(self.device) for m in self.metrics['val'] if isinstance(m, Metric)],
+            'test': [m.to(self.device) for m in self.metrics['test'] if isinstance(m, Metric)]
+        }
+
+    def on_test_start(self):
+        self.metrics['test'] = [m.to(self.device) if isinstance(m, Metric) else m for m in self.metrics['test']]
+
+
     def training_step(self, batch, batch_nb):               # 训练步
         loss, preds, targets, batch_size = self.do_forward(batch)
         self.log('train_loss', loss, prog_bar=True, on_step=True, on_epoch=True, batch_size=batch_size)
 
         preds, targets = detach_clone(preds), detach_clone(targets)
         if self.metrics:
-            self.do_metric(preds, targets, 'train', True, True)
+            self.do_metric(preds, targets, 'train', True, True, batch_size)
         self.messages['train_batch'] = (batch_nb, preds, targets)  # (batch_idx, preds, tagets)
         return loss
 
@@ -33,7 +44,7 @@ class GeneralTaskModule(LightningModule):
 
         preds, targets = detach_clone(preds), detach_clone(targets)
         if self.metrics:
-            self.do_metric(preds, targets, 'val', True, True)
+            self.do_metric(preds, targets, 'val', True, True, batch_size)
         self.messages['val_batch'] = (batch_nb, preds, targets)  # (batch_idx, preds, tagets)
         return {'val_loss': loss}
 
@@ -44,7 +55,7 @@ class GeneralTaskModule(LightningModule):
 
         preds, targets = detach_clone(preds), detach_clone(targets)
         if self.metrics:
-            self.do_metric(preds, targets, 'test', True, True)
+            self.do_metric(preds, targets, 'test', True, True, batch_size)
         self.messages['test_batch'] = (batch_nb, preds, targets)  # (batch_idx, preds, tagets)
         if loss is not None:
             return {'test_loss': loss}
@@ -69,15 +80,28 @@ class GeneralTaskModule(LightningModule):
             loss = self.loss_fn(preds, targets)
         else:
             loss = None
-        batch_size = batch[0].shape[0] if isinstance(batch, (tuple, list)) else batch.shape[0]
+        batch_size = self._batch_size(input_feat)
         return loss, preds, targets, batch_size
 
-    def do_metric(self, preds, targets, state, on_step, on_epoch):  # 指标计算
+    def do_metric(self, preds, targets, state, on_step, on_epoch, batch_size):  # 指标计算
         metrics = self.metrics[state]
         for metric in metrics:
             if isinstance(metric, Metric):
                 metric(preds, targets)
-                self.log(f"{state}_{metric.name}", metric, prog_bar=True, on_step=on_step, on_epoch=on_epoch, metric_attribute=metric, batch_size=preds.shape[0])
+                self.log(f"{state}_{metric.name}", metric, prog_bar=True, on_step=on_step, on_epoch=on_epoch, metric_attribute=metric, batch_size=batch_size)
             else:
                 value = metric(preds, targets)
-                self.log(f"{state}_{metric.name}_step", value, prog_bar=True, on_step=on_step, on_epoch=False, batch_size=preds.shape[0])
+                self.log(f"{state}_{metric.name}_step", value, prog_bar=True, on_step=on_step, on_epoch=False, batch_size=batch_size)
+
+    def _batch_size(self, inputs):
+        """检测batch size以用于输出日志"""
+        if isinstance(inputs, (tuple, list)):
+            data = inputs[0]
+        else:
+            data = inptus
+        if hasattr(data, 'shape'):
+            return data.shape[0]
+        elif hasattr(data, '__len__'):
+            return len(data)
+        else:
+            return 1
\ No newline at end of file
