@@ -98,6 +98,8 @@ class Trainer(PLTrainer):
             else:
                 if not hasattr(m, 'name'):
                     name = m.__name__ if hasattr(m, '__name__') else type(m).__name__
+                else:
+                    name = m.name
                 if just_for_test:
                     metrics_ready['test'].append(MetricBase(m, name))
                 else:
@@ -114,6 +116,10 @@ class Trainer(PLTrainer):
         return self.progress
 
     def test(self, test_dl=None, ckpt_path='best', pl_module=None, verbose=True, metrics=None, do_loss=True):
+        """
+        metrics: 一旦提供了test的metrics，则会将trainer中用于test的metrics覆盖，也就是说可以指定仅用于test的metrics
+        do_loss: 在测试时是否计算损失函数，当测试任务和训练任务数据不一致无法计算损失函数时，可设do_loss=False
+        """
         self.task_module.do_test_loss = do_loss
         if metrics is not None:  # 如果提供了仅用于test的metrics
             test_metrics = self._prepare_metrics(metrics, just_for_test=True)
